Models
===========


.. automodule:: cornac.models
    :members:

Recommender (Generic Class)
-----------------------------------------
.. automodule:: cornac.models.recommender
   :members:

Bilateral VAE for Collaborative Filtering (BiVAECF)
----------------------------------------------------
.. automodule:: cornac.models.bivaecf.recom_bivaecf
   :members:

Collaborative Context Poisson Factorization (C2PF)
----------------------------------------------------
.. automodule:: cornac.models.c2pf.recom_c2pf
   :members:

Multi-Task Explainable Recommendation (MTER)
----------------------------------------------------
.. automodule:: cornac.models.mter.recom_mter
   :members:

Neural Attention Rating Regression with Review-level Explanations (NARRE)
---------------------------------------------------------------------------
.. automodule:: cornac.models.narre.recom_narre
   :members:

Probabilistic Collaborative Representation Learning (PCRL)
------------------------------------------------------------
.. automodule:: cornac.models.pcrl.recom_pcrl
   :members:

VAE for Collaborative Filtering (VAECF)
----------------------------------------------------
.. automodule:: cornac.models.vaecf.recom_vaecf
   :members:

Conditional VAE for Collaborative Filtering (CVAECF)
-------------------------------------------------------
.. automodule:: cornac.models.cvaecf.recom_cvaecf
   :members:

Collaborative Variational Autoencoder (CVAE)
----------------------------------------------
.. automodule:: cornac.models.cvae.recom_cvae
   :members:

Generalized Matrix Factorization (GMF)
-----------------------------------------
.. automodule:: cornac.models.ncf.recom_gmf
   :members:

Indexable Bayesian Personalized Ranking (IBPR)
-----------------------------------------------
.. automodule:: cornac.models.ibpr.recom_ibpr
   :members:

Matrix Co-Factorization (MCF)
-----------------------------------------
.. automodule:: cornac.models.mcf.recom_mcf
   :members:

Multi-Layer Perceptron (MLP)
-----------------------------------------
.. automodule:: cornac.models.ncf.recom_mlp
   :members:

Neural Matrix Factorization (NeuMF/NCF)
----------------------------------------------
.. automodule:: cornac.models.ncf.recom_neumf
   :members:

Online Indexable Bayesian Personalized Ranking (OIBPR)
-----------------------------------------------------------
.. automodule:: cornac.models.online_ibpr.recom_online_ibpr
   :members:

Visual Matrix Factorization (VMF)
-----------------------------------------
.. automodule:: cornac.models.vmf.recom_vmf
   :members:

Collaborative Deep Ranking (CDR)
---------------------------------------
.. automodule:: cornac.models.cdr.recom_cdr
   :members:

Collaborative Ordinal Embedding (COE)
--------------------------------------------
.. automodule:: cornac.models.coe.recom_coe
   :members:

Convolutional Matrix Factorization (ConvMF)
--------------------------------------------------
.. automodule:: cornac.models.conv_mf.recom_convmf
   :members:

Spherical k-means (Skmeans)
----------------------------
.. automodule:: cornac.models.skm.recom_skmeans
   :members:

Visual Bayesian Personalized Ranking (VBPR)
-----------------------------------------------
.. automodule:: cornac.models.vbpr.recom_vbpr
   :members:

Collaborative Deep Learning (CDL)
---------------------------------------------
.. automodule:: cornac.models.cdl.recom_cdl
   :members:

Hierarchical Poisson Factorization (HPF)
--------------------------------------------
.. automodule:: cornac.models.hpf.recom_hpf
   :members:

Explicit Factor Model (EFM)
--------------------------------------------
.. automodule:: cornac.models.efm.recom_efm
   :members:

Social Bayesian Personalized Ranking (SBPR)
--------------------------------------------------
.. autoclass:: cornac.models.sbpr.recom_sbpr.SBPR
   :members:

Hidden Factors and Hidden Topics (HFT)
---------------------------------------------
.. automodule:: cornac.models.hft.recom_hft
   :members:

Weighted Bayesian Personalized Ranking (WBPR)
------------------------------------------------
.. autoclass:: cornac.models.bpr.recom_wbpr.WBPR
   :members:

Collaborative Topic Modeling (CTR)
-------------------------------------------
.. automodule:: cornac.models.ctr.recom_ctr
   :members:

Baseline Only
---------------------------------------------------
.. autoclass:: cornac.models.baseline_only.recom_bo
   :members:

Bayesian Personalized Ranking (BPR)
----------------------------------------------
.. autoclass:: cornac.models.bpr.recom_bpr.BPR
   :members:

Factorization Machines (FM)
-------------------------------------------
.. autoclass:: cornac.models.fm.recom_fm.FM
   :members

Global Average (GlobalAvg)
---------------------------------------------------------
.. automodule:: cornac.models.global_avg.recom_global_avg
   :members:

Item K-Nearest-Neighbors (ItemKNN)
--------------------------------------------------
.. autoclass:: cornac.models.knn.recom_knn.ItemKNN
   :members:

Matrix Factorization (MF)
------------------------------------------
.. automodule:: cornac.models.mf.recom_mf
   :members:

Maximum Margin Matrix Factorization (MMMF)
---------------------------------------------
.. automodule:: cornac.models.mmmf.recom_mmmf
   :members:

Most Popular (MostPop)
-----------------------------------------------------
.. automodule:: cornac.models.most_pop.recom_most_pop
   :members:

Non-negative Matrix Factorization (NMF)
--------------------------------------------
.. automodule:: cornac.models.nmf.recom_nmf
   :members:

Probabilitic Matrix Factorization (PMF)
--------------------------------------------
.. automodule:: cornac.models.pmf.recom_pmf
   :members:

Singular Value Decomposition (SVD)
-------------------------------------------
.. automodule:: cornac.models.svd.recom_svd
   :members:

Social Recommendation using PMF (SoRec)
------------------------------------------------
.. automodule:: cornac.models.sorec.recom_sorec
   :members:

User K-Nearest-Neighbors (UserKNN)
--------------------------------------------------
.. autoclass:: cornac.models.knn.recom_knn.UserKNN
   :members:   

Weighted Matrix Factorization (WMF)
--------------------------------------------------
.. automodule:: cornac.models.wmf.recom_wmf
   :members:
